==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/TLSSecurityProfileFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSSecurityProfileFluent<A extends TLSSecurityProfileFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCustom instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomTLSProfile getCustom();
  public CustomTLSProfile buildCustom();
  public A withCustom(CustomTLSProfile custom);
  public Boolean hasCustom();
  public TLSSecurityProfileFluent.CustomNested<A> withNewCustom();
  public TLSSecurityProfileFluent.CustomNested<A> withNewCustomLike(CustomTLSProfile item);
  public TLSSecurityProfileFluent.CustomNested<A> editCustom();
  public TLSSecurityProfileFluent.CustomNested<A> editOrNewCustom();
  public TLSSecurityProfileFluent.CustomNested<A> editOrNewCustomLike(CustomTLSProfile item);
  
  /**
   * This method has been deprecated, please use method buildIntermediate instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntermediateTLSProfile getIntermediate();
  public IntermediateTLSProfile buildIntermediate();
  public A withIntermediate(IntermediateTLSProfile intermediate);
  public Boolean hasIntermediate();
  public TLSSecurityProfileFluent.IntermediateNested<A> withNewIntermediate();
  public TLSSecurityProfileFluent.IntermediateNested<A> withNewIntermediateLike(IntermediateTLSProfile item);
  public TLSSecurityProfileFluent.IntermediateNested<A> editIntermediate();
  public TLSSecurityProfileFluent.IntermediateNested<A> editOrNewIntermediate();
  public TLSSecurityProfileFluent.IntermediateNested<A> editOrNewIntermediateLike(IntermediateTLSProfile item);
  
  /**
   * This method has been deprecated, please use method buildModern instead.
   * @return The buildable object.
   */
  @Deprecated
  public ModernTLSProfile getModern();
  public ModernTLSProfile buildModern();
  public A withModern(ModernTLSProfile modern);
  public Boolean hasModern();
  public TLSSecurityProfileFluent.ModernNested<A> withNewModern();
  public TLSSecurityProfileFluent.ModernNested<A> withNewModernLike(ModernTLSProfile item);
  public TLSSecurityProfileFluent.ModernNested<A> editModern();
  public TLSSecurityProfileFluent.ModernNested<A> editOrNewModern();
  public TLSSecurityProfileFluent.ModernNested<A> editOrNewModernLike(ModernTLSProfile item);
  
  /**
   * This method has been deprecated, please use method buildOld instead.
   * @return The buildable object.
   */
  @Deprecated
  public OldTLSProfile getOld();
  public OldTLSProfile buildOld();
  public A withOld(OldTLSProfile old);
  public Boolean hasOld();
  public TLSSecurityProfileFluent.OldNested<A> withNewOld();
  public TLSSecurityProfileFluent.OldNested<A> withNewOldLike(OldTLSProfile item);
  public TLSSecurityProfileFluent.OldNested<A> editOld();
  public TLSSecurityProfileFluent.OldNested<A> editOrNewOld();
  public TLSSecurityProfileFluent.OldNested<A> editOrNewOldLike(OldTLSProfile item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CustomNested<N> extends Nested<N>,CustomTLSProfileFluent<TLSSecurityProfileFluent.CustomNested<N>>{
    public N and();
    public N endCustom();
    
  }
  public interface IntermediateNested<N> extends Nested<N>,IntermediateTLSProfileFluent<TLSSecurityProfileFluent.IntermediateNested<N>>{
    public N and();
    public N endIntermediate();
    
  }
  public interface ModernNested<N> extends Nested<N>,ModernTLSProfileFluent<TLSSecurityProfileFluent.ModernNested<N>>{
    public N and();
    public N endModern();
    
  }
  public interface OldNested<N> extends Nested<N>,OldTLSProfileFluent<TLSSecurityProfileFluent.OldNested<N>>{
    public N and();
    public N endOld();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/TLSSecurityProfileFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSSecurityProfileFluent<A extends TLSSecurityProfileFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCustom instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomTLSProfile getCustom();
  public CustomTLSProfile buildCustom();
  public A withCustom(CustomTLSProfile custom);
  public Boolean hasCustom();
  public TLSSecurityProfileFluent.CustomNested<A> withNewCustom();
  public TLSSecurityProfileFluent.CustomNested<A> withNewCustomLike(CustomTLSProfile item);
  public TLSSecurityProfileFluent.CustomNested<A> editCustom();
  public TLSSecurityProfileFluent.CustomNested<A> editOrNewCustom();
  public TLSSecurityProfileFluent.CustomNested<A> editOrNewCustomLike(CustomTLSProfile item);
  
  /**
   * This method has been deprecated, please use method buildIntermediate instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntermediateTLSProfile getIntermediate();
  public IntermediateTLSProfile buildIntermediate();
  public A withIntermediate(IntermediateTLSProfile intermediate);
  public Boolean hasIntermediate();
  public TLSSecurityProfileFluent.IntermediateNested<A> withNewIntermediate();
  public TLSSecurityProfileFluent.IntermediateNested<A> withNewIntermediateLike(IntermediateTLSProfile item);
  public TLSSecurityProfileFluent.IntermediateNested<A> editIntermediate();
  public TLSSecurityProfileFluent.IntermediateNested<A> editOrNewIntermediate();
  public TLSSecurityProfileFluent.IntermediateNested<A> editOrNewIntermediateLike(IntermediateTLSProfile item);
  
  /**
   * This method has been deprecated, please use method buildModern instead.
   * @return The buildable object.
   */
  @Deprecated
  public ModernTLSProfile getModern();
  public ModernTLSProfile buildModern();
  public A withModern(ModernTLSProfile modern);
  public Boolean hasModern();
  public TLSSecurityProfileFluent.ModernNested<A> withNewModern();
  public TLSSecurityProfileFluent.ModernNested<A> withNewModernLike(ModernTLSProfile item);
  public TLSSecurityProfileFluent.ModernNested<A> editModern();
  public TLSSecurityProfileFluent.ModernNested<A> editOrNewModern();
  public TLSSecurityProfileFluent.ModernNested<A> editOrNewModernLike(ModernTLSProfile item);
  
  /**
   * This method has been deprecated, please use method buildOld instead.
   * @return The buildable object.
   */
  @Deprecated
  public OldTLSProfile getOld();
  public OldTLSProfile buildOld();
  public A withOld(OldTLSProfile old);
  public Boolean hasOld();
  public TLSSecurityProfileFluent.OldNested<A> withNewOld();
  public TLSSecurityProfileFluent.OldNested<A> withNewOldLike(OldTLSProfile item);
  public TLSSecurityProfileFluent.OldNested<A> editOld();
  public TLSSecurityProfileFluent.OldNested<A> editOrNewOld();
  public TLSSecurityProfileFluent.OldNested<A> editOrNewOldLike(OldTLSProfile item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CustomNested<N> extends Nested<N>,CustomTLSProfileFluent<TLSSecurityProfileFluent.CustomNested<N>>{
    public N and();
    public N endCustom();
    
  }
  public interface IntermediateNested<N> extends Nested<N>,IntermediateTLSProfileFluent<TLSSecurityProfileFluent.IntermediateNested<N>>{
    public N and();
    public N endIntermediate();
    
  }
  public interface ModernNested<N> extends Nested<N>,ModernTLSProfileFluent<TLSSecurityProfileFluent.ModernNested<N>>{
    public N and();
    public N endModern();
    
  }
  public interface OldNested<N> extends Nested<N>,OldTLSProfileFluent<TLSSecurityProfileFluent.OldNested<N>>{
    public N and();
    public N endOld();
    
  }
  
}
